@@ -1,7 +1,5 @@
 import signal
-import time
 from contextlib import contextmanager
-import xarray as xr
 
 
 class TimeoutException(Exception):
@@ -21,7 +19,7 @@ def time_limit(seconds):
         signal.alarm(0)
 
 
-def plot(self, vars=None, autoscale=True):
+def plot(self, vars=None, autoscale=True, out = None, **kwargs):
     from ncplot import view
 
     """
@@ -33,6 +31,12 @@ def plot(self, vars=None, autoscale=True):
     vars: str or list
         A string or list of the variables to plot
 
+    out: str
+        Name of output file if you want to save as html. Defaults to None.
+
+    **kwargs: Optional args to be sent to hvplot
+         
+
     Examples
     ------------
 
@@ -72,10 +76,10 @@ def plot(self, vars=None, autoscale=True):
             )
     if vars is None and len(self.variables) > 1:
         with time_limit(20):
-            return view(self[0], autoscale=autoscale)
+            return view(self[0], autoscale=autoscale, **kwargs)
 
     if type(vars) is list and len(vars) > 1:
         with time_limit(20):
-            return view(self[0], vars=vars, autoscale=autoscale)
+            return view(self[0], vars=vars, autoscale=autoscale, **kwargs)
 
-    return view(self[0], vars=vars, autoscale=autoscale)
+    return view(self[0], vars=vars, autoscale=autoscale, out = out, **kwargs)
